summaryrefslogtreecommitdiff
path: root/sw/source/core/inc/layfrm.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/inc/layfrm.hxx')
-rw-r--r--sw/source/core/inc/layfrm.hxx47
1 files changed, 24 insertions, 23 deletions
diff --git a/sw/source/core/inc/layfrm.hxx b/sw/source/core/inc/layfrm.hxx
index 5a62a8c46425..093549d057da 100644
--- a/sw/source/core/inc/layfrm.hxx
+++ b/sw/source/core/inc/layfrm.hxx
@@ -25,8 +25,8 @@
* for a copy of the LGPLv3 License.
*
************************************************************************/
-#ifndef _LAYFRM_HXX
-#define _LAYFRM_HXX
+#ifndef SW_LAYFRM_HXX
+#define SW_LAYFRM_HXX
#include "frame.hxx"
@@ -61,10 +61,10 @@ protected:
SwFrm *pLower;
- virtual SwTwips ShrinkFrm( SwTwips, BOOL bTst = FALSE, BOOL bInfo = FALSE );
- virtual SwTwips GrowFrm ( SwTwips, BOOL bTst = FALSE, BOOL bInfo = FALSE );
+ virtual SwTwips ShrinkFrm( SwTwips, sal_Bool bTst = sal_False, sal_Bool bInfo = sal_False );
+ virtual SwTwips GrowFrm ( SwTwips, sal_Bool bTst = sal_False, sal_Bool bInfo = sal_False );
- long CalcRel( const SwFmtFrmSize &rSz, BOOL bWidth ) const;
+ long CalcRel( const SwFmtFrmSize &rSz, sal_Bool bWidth ) const;
public:
// --> #i28701#
@@ -77,10 +77,10 @@ public:
//Proportionale Groessenanpassung der untergeordneten.
void ChgLowersProp( const Size& rOldSize );
- void AdjustColumns( const SwFmtCol *pCol, BOOL bAdjustAttributes );
+ void AdjustColumns( const SwFmtCol *pCol, sal_Bool bAdjustAttributes );
void ChgColumns( const SwFmtCol &rOld, const SwFmtCol &rNew,
- const BOOL bChgFtn = FALSE );
+ const sal_Bool bChgFtn = sal_False );
//Painted die Column-Trennlinien fuer die innenliegenden Columns.
@@ -89,7 +89,7 @@ public:
virtual bool FillSelection( SwSelectionList& rList, const SwRect& rRect ) const;
- virtual BOOL GetCrsrOfst( SwPosition *, Point&,
+ virtual sal_Bool GetCrsrOfst( SwPosition *, Point&,
SwCrsrMoveState* = 0 ) const;
virtual void Cut();
@@ -97,16 +97,17 @@ public:
//sucht den dichtesten Cntnt zum SPoint, wird bei Seiten, Flys und Cells
//benutzt wenn GetCrsrOfst versagt hat.
- const SwCntntFrm* GetCntntPos( Point &rPoint, const BOOL bDontLeave,
- const BOOL bBodyOnly = FALSE,
- const BOOL bCalc = FALSE,
+ const SwCntntFrm* GetCntntPos( Point &rPoint, const sal_Bool bDontLeave,
+ const sal_Bool bBodyOnly = sal_False,
+ const sal_Bool bCalc = sal_False,
const SwCrsrMoveState *pCMS = 0,
- const BOOL bDefaultExpand = TRUE ) const;
+ const sal_Bool bDefaultExpand = sal_True ) const;
SwLayoutFrm( SwFrmFmt* );
~SwLayoutFrm();
- virtual void Paint( const SwRect&, const SwPrtOptions *pPrintData = NULL ) const;
+ virtual void Paint( SwRect const&,
+ SwPrintData const*const pPrintData = NULL ) const;
const SwFrm *Lower() const { return pLower; }
SwFrm *Lower() { return pLower; }
const SwCntntFrm *ContainsCntnt() const;
@@ -120,17 +121,17 @@ public:
// investigated for sections.
const SwFrm *ContainsAny( const bool _bInvestigateFtnForSections = false ) const;
inline SwFrm *ContainsAny( const bool _bInvestigateFtnForSections = false );
- BOOL IsAnLower( const SwFrm * ) const;
+ sal_Bool IsAnLower( const SwFrm * ) const;
- const SwFrmFmt *GetFmt() const { return (const SwFrmFmt*)GetDep(); }
- SwFrmFmt *GetFmt() { return (SwFrmFmt*)GetDep(); }
- void SetFrmFmt( SwFrmFmt* );
+ virtual const SwFrmFmt *GetFmt() const;
+ virtual SwFrmFmt *GetFmt();
+ void SetFrmFmt( SwFrmFmt* );
//Verschieben der Ftns aller Lower - ab dem StartCntnt.
//TRUE wenn mindestens eine Ftn verschoben wurde.
//Ruft das Update der Seitennummer wenn bFtnNums gesetzt ist.
- BOOL MoveLowerFtns( SwCntntFrm *pStart, SwFtnBossFrm *pOldBoss,
- SwFtnBossFrm *pNewBoss, const BOOL bFtnNums );
+ sal_Bool MoveLowerFtns( SwCntntFrm *pStart, SwFtnBossFrm *pOldBoss,
+ SwFtnBossFrm *pNewBoss, const sal_Bool bFtnNums );
// --> #i28701# - change purpose of method and its name
// --> #i44016# - add parameter <_bUnlockPosOfObjs> to
@@ -188,12 +189,12 @@ inline SwFrm* SwLayoutFrm::ContainsAny( const bool _bInvestigateFtnForSections )
}
// Diese SwFrm-inlines sind hier, damit frame.hxx nicht layfrm.hxx includen muss
-inline BOOL SwFrm::IsColBodyFrm() const
+inline sal_Bool SwFrm::IsColBodyFrm() const
{
return nType == FRMC_BODY && GetUpper()->IsColumnFrm();
}
-inline BOOL SwFrm::IsPageBodyFrm() const
+inline sal_Bool SwFrm::IsPageBodyFrm() const
{
return nType == FRMC_BODY && GetUpper()->IsPageFrm();
}
@@ -203,6 +204,6 @@ inline SwFrm* SwLayoutFrm::GetLastLower()
return const_cast<SwFrm*>(static_cast<const SwLayoutFrm*>(this)->GetLastLower());
}
-#endif //_LAYFRM_HXX
+#endif // SW_LAYFRM_HXX
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
@@ -120,17 +121,17 @@ public:
//Verschieben der Ftns aller Lower - ab dem StartCntnt.
- //TRUE wenn mindestens eine Ftn verschoben wurde.
+ //sal_True wenn mindestens eine Ftn verschoben wurde.
//Ruft das Update der Seitennummer wenn bFtnNums gesetzt ist.